<?php
// *********************************************************
// NOTICE: All rights reserved. This material contains the
// trade secrets and confidential information of JDSU
// which embody substantial creative effort,
// ideas and expressions. No part of this material may be
// reproduced or transmitted in any form or by any means,
// electronic, mechanical, optical or otherwise, including
// photocopying and recording or in connection with any
// information storage or retrieval system, without
// specific written permission from JDSU
// Copyright JDSU 2013. All rights reserved.
// *********************************************************
namespace app\view;

use app\util\SMTIOException;

/**
 * Flush the otdr trace buffer for the given otdr trace file name.
 *
 * @author Sylvain Desplat
 */
class SMTOtdrTraceFileDownloadPage extends SMTOtdrTraceBaseDownloadPage
{
	/**
	 * Construct the builder of otdr trace file.
	 * 
	 * @param string $otdrTracefileName
	 * @param string $otdrTraceType SMTOtdrTraceType::OTU_REFERENCE_TRACE, SMTOtdrTraceType::SMARTOTU_ACQUISITION_TRACE, SMTOtdrTraceType::LAST_TEST_ACQUISITION_TRACE
	 * 
	 */
	function __construct( $otdrTracefileName, $otdrTraceType )
	{
		$this->otdrTracefileName = $otdrTracefileName;
		$this->otdrTraceType = $otdrTraceType;
	}

	/**
	 * Flush the otdr trace buffer for the given otdr trace file name
	 *
	 */
	function generatePage()
	{	    
	    //test file exists:
		if( $this->checkFileExtension($this->otdrTracefileName) && $this->checkDirectory($this->otdrTracefileName) && ($handle = fopen($this->otdrTracefileName ,"rb")) != FALSE )
        {            
        	//open buffering
         	header('Content-Type: application/octet-stream;');
         	header('Content-Disposition: attachment; filename="'.basename( $this->otdrTracefileName ).'";');
         	header('Cache-Control: no-cache, must-revalidate');
         	header('Expires: 0');         	
        	ob_start();            
            while ( !feof($handle) ) 
            {
                echo fread($handle , 8192 );
            }            
            fclose($handle);     

            //end buffering and flush
            return ob_end_flush();
        }        
        else
        {
        	throw new SMTIOException( SMTIOException::FILE_NOT_FOUND, rawurlencode(basename($this->otdrTracefileName)) );
        }        
	}
}
?>